Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.FamilieGruppeSchlank Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.FamilieGruppeSchlank einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.FamilieGruppeSchlank) | Gemeinde_Modelle.FamilieGruppeSchlank |
__str__(self) (Definiert in Gemeinde_Modelle.FamilieGruppeSchlank) | Gemeinde_Modelle.FamilieGruppeSchlank |
R_familie (Definiert in Gemeinde_Modelle.FamilieGruppeSchlank) | Gemeinde_Modelle.FamilieGruppeSchlank | static
R_gruppe (Definiert in Gemeinde_Modelle.FamilieGruppeSchlank) | Gemeinde_Modelle.FamilieGruppeSchlank | static